signet-node-config 0.17.1

Environment-driven configuration for the Signet node
docs.rs failed to build signet-node-config-0.17.1
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.

Signet Node Config

Configuration objects for the Signet Node

This library contains the following:

  • SignetNodeConfig - The main configuration object for a Signet Node. This struct can be loaded from the environment, or deserialized from a JSON file.